==> kpogre-1.2.7.tar.gz: kpogre-1.2.7/kpogre/DbObjects/kpgsequencesfolder.h <==
/***************************************************************************
                          kpgsequencesfolder  -  description
                             -------------------
    begin                : Ne no 1 2004
    copyright            : (C) 2004 by Lumir Vanek
    email                : lvanek@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KPGSEQUENCESFOLDER_H
#define KPGSEQUENCESFOLDER_H

#include "kpgitemsfolder.h"

class KPGSchema;

/**
Item that hold sequences list

@author Lumir Vanek
*/

class KPGConnection;

class KPGSequencesFolder : public KPGItemsFolder
{
public:
    KPGSequencesFolder(KPGSchema *, pqxx::oid);
    ~KPGSequencesFolder();
		
		virtual eNodeType type() const { return nodeFolderSequences; }
		bool refresh(pqxx::work &);
		void displayProperties(QWidget *);
		pqxx::result resultSequences() const { return m_pqxxResultSequences; }
			
protected:
  // results that will be displaied in properties window
  pqxx::result m_pqxxResultSequences;
	
	// Parent namespace OID
	pqxx::oid m_oidNameSpace;
};

#endif

==> kpogre-1.6.6.tar.gz: kpogre-1.6.6/kpogre/DbObjects/kpgsequencesfolder.h <==
/***************************************************************************
                          kpgsequencesfolder  -  description
                             -------------------
    begin                : Ne no 1 2004
    copyright            : (C) 2004 by Lumir Vanek
    email                : lvanek@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KPGSEQUENCESFOLDER_H
#define KPGSEQUENCESFOLDER_H

#include "kpgitemsfolder.h"

class KPGSchema;

/**
  * Item that hold sequences list
  *
  * @author Lumir Vanek
  */
class KPGConnection;

class KPGSequencesFolder : public KPGItemsFolder
{
public:
    KPGSequencesFolder(KPGSchema *, pqxx::oid);
    ~KPGSequencesFolder();
		
	virtual eNodeType type() const { return nodeFolderSequences; }
	
	// Refresh item, ald also childs objects
	void refresh() throw(const KPGSqlException &);
	
	const pqxx::result & resultSequences() const { return m_pqxxResultSequences; }
			
protected:
  	// results that will be displaied in properties window
  	pqxx::result m_pqxxResultSequences;
	
	// Parent namespace OID
	pqxx::oid m_oidNameSpace;
};

#endif
